==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_entities/systemequipment_001/SystemParentHierarchy.java <==

package net.datastream.schemas.mp_entities.systemequipment_001;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.LOCATIONID_Type;
import net.datastream.schemas.mp_fields.LOCATIONPARENT_Type;
import net.datastream.schemas.mp_fields.SYSTEMPARENT_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SYSTEMID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOCATIONID" minOccurs="0"/>
 *         &lt;choice minOccurs="0">
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPENDENTLOCATION" minOccurs="0"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPENDENTSYSTEM" minOccurs="0"/>
 *           &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPENDENTPRIMARYSYSTEM" minOccurs="0"/>
 *         &lt;/choice>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NONDEPENDENTSYSTEM" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NONDEPENDENTPRIMARYSYSTEM" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "systemid",
    "type",
    "locationid",
    "dependentlocation",
    "dependentsystem",
    "dependentprimarysystem",
    "nondependentsystem",
    "nondependentprimarysystem"
})
@XmlRootElement(name = "SystemParentHierarchy")
public class SystemParentHierarchy {

    @XmlElement(name = "SYSTEMID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type systemid;
    @XmlElement(name = "TYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type type;
    @XmlElement(name = "LOCATIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected LOCATIONID_Type locationid;
    @XmlElement(name = "DEPENDENTLOCATION", namespace = "http://schemas.datastream.net/MP_fields")
    protected LOCATIONPARENT_Type dependentlocation;
    @XmlElement(name = "DEPENDENTSYSTEM", namespace = "http://schemas.datastream.net/MP_fields")
    protected SYSTEMPARENT_Type dependentsystem;
    @XmlElement(name = "DEPENDENTPRIMARYSYSTEM", namespace = "http://schemas.datastream.net/MP_fields")
    protected SYSTEMPARENT_Type dependentprimarysystem;
    @XmlElement(name = "NONDEPENDENTSYSTEM", namespace = "http://schemas.datastream.net/MP_fields")
    protected List<SYSTEMPARENT_Type> nondependentsystem;
    @XmlElement(name = "NONDEPENDENTPRIMARYSYSTEM", namespace = "http://schemas.datastream.net/MP_fields")
    protected SYSTEMPARENT_Type nondependentprimarysystem;

    /**
     * Obtient la valeur de la propriété systemid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getSYSTEMID() {
        return systemid;
    }

    /**
     * Définit la valeur de la propriété systemid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setSYSTEMID(EQUIPMENTID_Type value) {
        this.systemid = value;
    }

    /**
     * Obtient la valeur de la propriété type.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTYPE() {
        return type;
    }

    /**
     * Définit la valeur de la propriété type.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTYPE(TYPE_Type value) {
        this.type = value;
    }

    /**
     * Obtient la valeur de la propriété locationid.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public LOCATIONID_Type getLOCATIONID() {
        return locationid;
    }

    /**
     * Définit la valeur de la propriété locationid.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public void setLOCATIONID(LOCATIONID_Type value) {
        this.locationid = value;
    }

    /**
     * Obtient la valeur de la propriété dependentlocation.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONPARENT_Type }
     *     
     */
    public LOCATIONPARENT_Type getDEPENDENTLOCATION() {
        return dependentlocation;
    }

    /**
     * Définit la valeur de la propriété dependentlocation.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONPARENT_Type }
     *     
     */
    public void setDEPENDENTLOCATION(LOCATIONPARENT_Type value) {
        this.dependentlocation = value;
    }

    /**
     * Obtient la valeur de la propriété dependentsystem.
     * 
     * @return
     *     possible object is
     *     {@link SYSTEMPARENT_Type }
     *     
     */
    public SYSTEMPARENT_Type getDEPENDENTSYSTEM() {
        return dependentsystem;
    }

    /**
     * Définit la valeur de la propriété dependentsystem.
     * 
     * @param value
     *     allowed object is
     *     {@link SYSTEMPARENT_Type }
     *     
     */
    public void setDEPENDENTSYSTEM(SYSTEMPARENT_Type value) {
        this.dependentsystem = value;
    }

    /**
     * Obtient la valeur de la propriété dependentprimarysystem.
     * 
     * @return
     *     possible object is
     *     {@link SYSTEMPARENT_Type }
     *     
     */
    public SYSTEMPARENT_Type getDEPENDENTPRIMARYSYSTEM() {
        return dependentprimarysystem;
    }

    /**
     * Définit la valeur de la propriété dependentprimarysystem.
     * 
     * @param value
     *     allowed object is
     *     {@link SYSTEMPARENT_Type }
     *     
     */
    public void setDEPENDENTPRIMARYSYSTEM(SYSTEMPARENT_Type value) {
        this.dependentprimarysystem = value;
    }

    /**
     * Gets the value of the nondependentsystem property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the nondependentsystem property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNONDEPENDENTSYSTEM().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link SYSTEMPARENT_Type }
     * 
     * 
     */
    public List<SYSTEMPARENT_Type> getNONDEPENDENTSYSTEM() {
        if (nondependentsystem == null) {
            nondependentsystem = new ArrayList<SYSTEMPARENT_Type>();
        }
        return this.nondependentsystem;
    }

    /**
     * Obtient la valeur de la propriété nondependentprimarysystem.
     * 
     * @return
     *     possible object is
     *     {@link SYSTEMPARENT_Type }
     *     
     */
    public SYSTEMPARENT_Type getNONDEPENDENTPRIMARYSYSTEM() {
        return nondependentprimarysystem;
    }

    /**
     * Définit la valeur de la propriété nondependentprimarysystem.
     * 
     * @param value
     *     allowed object is
     *     {@link SYSTEMPARENT_Type }
     *     
     */
    public void setNONDEPENDENTPRIMARYSYSTEM(SYSTEMPARENT_Type value) {
        this.nondependentprimarysystem = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/systemequipment_001/SystemParentHierarchy.java <==

package net.datastream.schemas.mp_entities.systemequipment_001;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.LOCATIONID_Type;
import net.datastream.schemas.mp_fields.LOCATIONPARENT_Type;
import net.datastream.schemas.mp_fields.SYSTEMPARENT_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SYSTEMID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TYPE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}LOCATIONID" minOccurs="0"/>
 *         <choice minOccurs="0">
 *           <element ref="{http://schemas.datastream.net/MP_fields}DEPENDENTLOCATION" minOccurs="0"/>
 *           <element ref="{http://schemas.datastream.net/MP_fields}DEPENDENTSYSTEM" minOccurs="0"/>
 *           <element ref="{http://schemas.datastream.net/MP_fields}DEPENDENTPRIMARYSYSTEM" minOccurs="0"/>
 *         </choice>
 *         <element ref="{http://schemas.datastream.net/MP_fields}NONDEPENDENTSYSTEM" maxOccurs="unbounded" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}NONDEPENDENTPRIMARYSYSTEM" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "systemid",
    "type",
    "locationid",
    "dependentlocation",
    "dependentsystem",
    "dependentprimarysystem",
    "nondependentsystem",
    "nondependentprimarysystem"
})
@XmlRootElement(name = "SystemParentHierarchy")
public class SystemParentHierarchy {

    @XmlElement(name = "SYSTEMID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type systemid;
    @XmlElement(name = "TYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type type;
    @XmlElement(name = "LOCATIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected LOCATIONID_Type locationid;
    @XmlElement(name = "DEPENDENTLOCATION", namespace = "http://schemas.datastream.net/MP_fields")
    protected LOCATIONPARENT_Type dependentlocation;
    @XmlElement(name = "DEPENDENTSYSTEM", namespace = "http://schemas.datastream.net/MP_fields")
    protected SYSTEMPARENT_Type dependentsystem;
    @XmlElement(name = "DEPENDENTPRIMARYSYSTEM", namespace = "http://schemas.datastream.net/MP_fields")
    protected SYSTEMPARENT_Type dependentprimarysystem;
    @XmlElement(name = "NONDEPENDENTSYSTEM", namespace = "http://schemas.datastream.net/MP_fields")
    protected List<SYSTEMPARENT_Type> nondependentsystem;
    @XmlElement(name = "NONDEPENDENTPRIMARYSYSTEM", namespace = "http://schemas.datastream.net/MP_fields")
    protected SYSTEMPARENT_Type nondependentprimarysystem;

    /**
     * Gets the value of the systemid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getSYSTEMID() {
        return systemid;
    }

    /**
     * Sets the value of the systemid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setSYSTEMID(EQUIPMENTID_Type value) {
        this.systemid = value;
    }

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTYPE() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTYPE(TYPE_Type value) {
        this.type = value;
    }

    /**
     * Gets the value of the locationid property.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public LOCATIONID_Type getLOCATIONID() {
        return locationid;
    }

    /**
     * Sets the value of the locationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONID_Type }
     *     
     */
    public void setLOCATIONID(LOCATIONID_Type value) {
        this.locationid = value;
    }

    /**
     * Gets the value of the dependentlocation property.
     * 
     * @return
     *     possible object is
     *     {@link LOCATIONPARENT_Type }
     *     
     */
    public LOCATIONPARENT_Type getDEPENDENTLOCATION() {
        return dependentlocation;
    }

    /**
     * Sets the value of the dependentlocation property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOCATIONPARENT_Type }
     *     
     */
    public void setDEPENDENTLOCATION(LOCATIONPARENT_Type value) {
        this.dependentlocation = value;
    }

    /**
     * Gets the value of the dependentsystem property.
     * 
     * @return
     *     possible object is
     *     {@link SYSTEMPARENT_Type }
     *     
     */
    public SYSTEMPARENT_Type getDEPENDENTSYSTEM() {
        return dependentsystem;
    }

    /**
     * Sets the value of the dependentsystem property.
     * 
     * @param value
     *     allowed object is
     *     {@link SYSTEMPARENT_Type }
     *     
     */
    public void setDEPENDENTSYSTEM(SYSTEMPARENT_Type value) {
        this.dependentsystem = value;
    }

    /**
     * Gets the value of the dependentprimarysystem property.
     * 
     * @return
     *     possible object is
     *     {@link SYSTEMPARENT_Type }
     *     
     */
    public SYSTEMPARENT_Type getDEPENDENTPRIMARYSYSTEM() {
        return dependentprimarysystem;
    }

    /**
     * Sets the value of the dependentprimarysystem property.
     * 
     * @param value
     *     allowed object is
     *     {@link SYSTEMPARENT_Type }
     *     
     */
    public void setDEPENDENTPRIMARYSYSTEM(SYSTEMPARENT_Type value) {
        this.dependentprimarysystem = value;
    }

    /**
     * Gets the value of the nondependentsystem property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a {@code set} method for the nondependentsystem property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNONDEPENDENTSYSTEM().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link SYSTEMPARENT_Type }
     * 
     * 
     * @return
     *     The value of the nondependentsystem property.
     */
    public List<SYSTEMPARENT_Type> getNONDEPENDENTSYSTEM() {
        if (nondependentsystem == null) {
            nondependentsystem = new ArrayList<>();
        }
        return this.nondependentsystem;
    }

    /**
     * Gets the value of the nondependentprimarysystem property.
     * 
     * @return
     *     possible object is
     *     {@link SYSTEMPARENT_Type }
     *     
     */
    public SYSTEMPARENT_Type getNONDEPENDENTPRIMARYSYSTEM() {
        return nondependentprimarysystem;
    }

    /**
     * Sets the value of the nondependentprimarysystem property.
     * 
     * @param value
     *     allowed object is
     *     {@link SYSTEMPARENT_Type }
     *     
     */
    public void setNONDEPENDENTPRIMARYSYSTEM(SYSTEMPARENT_Type value) {
        this.nondependentprimarysystem = value;
    }

}
